@@ -32,22 +32,25 @@ import fnmatch
 import logging
 import argparse
 import shutil
+import ast
 
 # Paths
 CLIENT_DIR = Path(__file__).parent
-HEADER_DIR = os.path.join(CLIENT_DIR, "templates")
-SPEC_DIR = os.path.join(CLIENT_DIR, "spec")
-POLARIS_MANAGEMENT_SPEC = os.path.join(SPEC_DIR, "polaris-management-service.yml")
-ICEBERG_CATALOG_SPEC = os.path.join(SPEC_DIR, "iceberg-rest-catalog-open-api.yaml")
-POLARIS_CATALOG_SPEC = os.path.join(SPEC_DIR, "polaris-catalog-service.yaml")
-OPEN_API_GENERATOR_IGNORE = os.path.join(CLIENT_DIR, ".openapi-generator-ignore")
+HEADER_DIR = CLIENT_DIR / "templates"
+SPEC_DIR = CLIENT_DIR / "spec"
+POLARIS_MANAGEMENT_SPEC = SPEC_DIR / "polaris-management-service.yml"
+ICEBERG_CATALOG_SPEC = SPEC_DIR / "iceberg-rest-catalog-open-api.yaml"
+POLARIS_CATALOG_SPEC = SPEC_DIR / "polaris-catalog-service.yaml"
+OPEN_API_GENERATOR_IGNORE = CLIENT_DIR / ".openapi-generator-ignore"
 
 # Open API Generator Configs
 PACKAGE_NAME_POLARIS_MANAGEMENT = (
-    "--additional-properties=packageName=polaris.management"
+  "--additional-properties=packageName=apache_polaris.sdk.management"
 )
-PACKAGE_NAME_POLARIS_CATALOG = "--additional-properties=packageName=polaris.catalog"
-PYTHON_VERSION = "--additional-properties=pythonVersion=3.9"
+PACKAGE_NAME_POLARIS_CATALOG = (
+  "--additional-properties=packageName=apache_polaris.sdk.catalog"
+)
+PYTHON_VERSION = "--additional-properties=pythonVersion=3.10"
 
 # Cleanup
 KEEP_TEST_FILES = [
@@ -55,19 +58,20 @@ KEEP_TEST_FILES = [
 ]
 EXCLUDE_PATHS = [
     Path(".gitignore"),
-    Path(".openapi-generator/"),
+    Path(".openapi-generator"),
     Path(".openapi-generator-ignore"),
-    Path(".pytest_cache/"),
+    Path(".pytest_cache"),
     Path("test/test_cli_parsing.py"),
-    Path("cli/"),
-    Path("polaris/__pycache__/"),
-    Path("polaris/catalog/__pycache__/"),
-    Path("polaris/catalog/models/__pycache__/"),
-    Path("polaris/catalog/api/__pycache__/"),
-    Path("polaris/management/__pycache__/"),
-    Path("polaris/management/models/__pycache__/"),
-    Path("polaris/management/api/__pycache__/"),
-    Path("integration_tests/"),
+    Path("apache_polaris/__pycache__"),
+    Path("apache_polaris/cli"),
+    Path("apache_polaris/sdk/__pycache__"),
+    Path("apache_polaris/sdk/catalog/__pycache__"),
+    Path("apache_polaris/sdk/catalog/models/__pycache__"),
+    Path("apache_polaris/sdk/catalog/api/__pycache__"),
+    Path("apache_polaris/sdk/management/__pycache__"),
+    Path("apache_polaris/sdk/management/models/__pycache__"),
+    Path("apache_polaris/sdk/management/api/__pycache__"),
+    Path("integration_tests"),
     Path(".github/workflows/python.yml"),
     Path(".gitlab-ci.yml"),
     Path("pyproject.toml"),
@@ -82,9 +86,9 @@ EXCLUDE_PATHS = [
     Path("README.md"),
     Path("generate_clients.py"),
     Path(".venv"),
-    Path("dist/"),
-    Path("templates/"),
-    Path("spec/"),
+    Path("dist"),
+    Path("templates"),
+    Path("spec"),
     Path("PKG-INFO"),
 ]
 EXCLUDE_EXTENSIONS = [
@@ -219,64 +223,56 @@ def _prepend_header_to_file(file_path: Path, header_file_path: Path) -> None:
 
 def prepend_licenses() -> None:
     logger.info("Re-applying license headers...")
+
+    # Combine all paths to exclude into one set.
+    all_excluded_paths = set(EXCLUDE_PATHS) | set(KEEP_TEST_FILES)
+
     for file_path in CLIENT_DIR.rglob("*"):
-        if file_path.is_file():
-            relative_file_path = file_path.relative_to(CLIENT_DIR)
-            file_extension = ""
-            # If it's a "dotfile" like .keep
-            if (
-                relative_file_path.name.startswith(".")
-                and "." not in relative_file_path.name[1:]
-            ):
-                # e.g., for '.keep', this is 'keep'
-                file_extension = relative_file_path.name.lstrip(".")
-            else:
-                # For standard files like generate_clients.py
-                file_extension = file_path.suffix.lstrip(".")
+        if not file_path.is_file():
+            continue
 
-            # Check if extension is excluded
-            if file_extension in EXCLUDE_EXTENSIONS:
-                logger.debug(f"{relative_file_path}: skipped (extension excluded)")
-                continue
+        relative_file_path = file_path.relative_to(CLIENT_DIR)
 
-            is_excluded = False
-            # Combine EXCLUDE_PATHS and KEEP_TEST_FILES for comprehensive exclusion check
-            # Convert Path objects in EXCLUDE_PATHS to strings for fnmatch compatibility
-            # Ensure patterns ending with '/' are handled for directory matching
-            all_exclude_patterns = [
-                str(p) + ("/" if p.is_dir() else "") for p in EXCLUDE_PATHS
-            ] + [str(p) for p in KEEP_TEST_FILES]
+        # Determine file extension, handling dotfiles.
+        file_extension = ""
+        if (
+            relative_file_path.name.startswith(".")
+            and "." not in relative_file_path.name[1:]
+        ):
+            file_extension = relative_file_path.name.lstrip(".")
+        else:
+            file_extension = relative_file_path.suffix.lstrip(".")
 
-            for exclude_pattern_str in all_exclude_patterns:
-                # Handle direct file match or if the file is within an excluded directory
-                if fnmatch.fnmatch(str(relative_file_path), exclude_pattern_str) or (
-                    exclude_pattern_str.endswith("/")
-                    and str(relative_file_path).startswith(exclude_pattern_str)
-                ):
-                    is_excluded = True
-                    break
+        if file_extension in EXCLUDE_EXTENSIONS:
+            logger.debug(f"{relative_file_path}: skipped (extension excluded)")
+            continue
 
-            if is_excluded:
-                logger.debug(f"{relative_file_path}: skipped (path excluded)")
-                continue
+        # Check if the path should be excluded.
+        is_excluded = False
+        for excluded_path in all_excluded_paths:
+            if relative_file_path == excluded_path or excluded_path in relative_file_path.parents:
+                is_excluded = True
+                break
 
-            header_file_path = Path(
-                os.path.join(HEADER_DIR, f"header-{file_extension}.txt")
-            )
+        if is_excluded:
+            logger.debug(f"{relative_file_path}: skipped (path excluded)")
+            continue
 
-            if header_file_path.is_file():
-                _prepend_header_to_file(file_path, header_file_path)
-                logger.debug(f"{relative_file_path}: updated")
-            else:
-                logger.error(f"No header compatible with file {relative_file_path}")
-                sys.exit(2)
+        header_file_path = HEADER_DIR / f"header-{file_extension}.txt"
+
+        if header_file_path.is_file():
+            _prepend_header_to_file(file_path, header_file_path)
+            logger.debug(f"{relative_file_path}: updated")
+        else:
+            logger.error(f"No header compatible with file {relative_file_path}")
+            sys.exit(2)
     logger.info("License fix complete.")
 
 
 def prepare_spec_dir():
     logger.info("Preparing spec directory...")
     spec_dir = Path(SPEC_DIR)
-    spec_source_dir = Path(os.path.join(CLIENT_DIR.parent.parent, "spec"))
+    spec_source_dir = CLIENT_DIR.parent.parent / "spec"
 
     if spec_source_dir.is_dir():
         logger.info(f"Copying spec directory from {spec_source_dir} to {spec_dir}")
@@ -303,9 +299,53 @@ def build() -> None:
     generate_polaris_management_client()
     generate_polaris_catalog_client()
     generate_iceberg_catalog_client()
+    fix_catalog_models_init()
     prepend_licenses()
 
 
+def fix_catalog_models_init() -> None:
+    """
+    Regenerate the `apache_polaris.sdk.catalog.models.__init__.py` file by consolidating
+    imports for all model classes found under `apache_polaris/sdk/catalog/models`.
+
+    This ensures that rerunning the OpenAPI Generator (which overwrites `__init__.py`)
+    does not cause missing imports for earlier generated model files.
+    """
+    logger.info("Fixing catalog models __init__.py...")
+    models_dir = CLIENT_DIR / "apache_polaris" / "sdk" / "catalog" / "models"
+    init_py = models_dir / "__init__.py"
+
+    # Get all python files in the models directory except __init__.py
+    model_files = [
+        f for f in models_dir.glob("*.py") if f.is_file() and f.name != "__init__.py"
+    ]
+
+    # Generate import statements
+    imports = []
+    for model_file in sorted(model_files):
+        module_name = model_file.stem
+        with open(model_file, "r") as f:
+            tree = ast.parse(f.read())
+        class_name = None
+        for node in ast.walk(tree):
+            if isinstance(node, ast.ClassDef):
+                # Find the first class that doesn't start with an underscore
+                if not node.name.startswith("_"):
+                    class_name = node.name
+                    break
+        if class_name:
+            imports.append(
+                f"from apache_polaris.sdk.catalog.models.{module_name} import {class_name}"
+            )
+        else:
+            logger.warning(f"Could not find a suitable class in {model_file}")
+
+    # Write the new __init__.py
+    with open(init_py, "w") as f:
+        f.write("\n".join(sorted(imports)))
+    logger.info("Catalog models __init__.py fixed.")
+
+
 def main():
     parser = argparse.ArgumentParser(description="Generate Polaris Python clients.")
     parser.add_argument(
