@@ -19,28 +19,29 @@
 
 import json
 import os.path
-import time
-
 import pytest
+import time
+from pyiceberg.catalog import Catalog as PyIcebergCatalog
+from pyiceberg.schema import Schema
 
-from integration_tests.conftest import format_namespace
-from polaris.catalog import (
+from apache_polaris.sdk.catalog import (
     CreateNamespaceRequest,
     CreateTableRequest,
     ModelSchema,
     TableIdentifier,
     IcebergCatalogAPI,
 )
-from polaris.catalog.models.attach_policy_request import AttachPolicyRequest
-from polaris.catalog.models.create_policy_request import CreatePolicyRequest
-from polaris.catalog.models.detach_policy_request import DetachPolicyRequest
-from polaris.catalog.models.policy_attachment_target import PolicyAttachmentTarget
-from polaris.catalog.models.update_policy_request import UpdatePolicyRequest
-from polaris.catalog.exceptions import NotFoundException
-from polaris.catalog.api.policy_api import PolicyAPI
-from pyiceberg.schema import Schema
-from polaris.management import Catalog
-from pyiceberg.catalog import Catalog as PyIcebergCatalog
+from apache_polaris.sdk.catalog.api.policy_api import PolicyAPI
+from apache_polaris.sdk.catalog.exceptions import NotFoundException
+from apache_polaris.sdk.catalog.models.attach_policy_request import AttachPolicyRequest
+from apache_polaris.sdk.catalog.models.create_policy_request import CreatePolicyRequest
+from apache_polaris.sdk.catalog.models.detach_policy_request import DetachPolicyRequest
+from apache_polaris.sdk.catalog.models.policy_attachment_target import (
+    PolicyAttachmentTarget,
+)
+from apache_polaris.sdk.catalog.models.update_policy_request import UpdatePolicyRequest
+from apache_polaris.sdk.management import Catalog
+from integration_tests.conftest import format_namespace
 
 
 def test_create_namespace(
@@ -271,6 +272,51 @@ def test_policies(
         assert updated_policy.policy.description == updated_policy_description
         assert json.loads(updated_policy.policy.content) == updated_policy_content
 
+        # ATTACH to catalog
+        test_policy_api.attach_policy(
+            prefix=test_catalog.name,
+            namespace=namespace_name,
+            policy_name=policy_name,
+            attach_policy_request=AttachPolicyRequest(
+                target=PolicyAttachmentTarget(type="catalog")
+            ),
+        )
+
+        # GET APPLICABLE on catalog
+        applicable_policies_catalog = test_policy_api.get_applicable_policies(
+            prefix=test_catalog.name
+        )
+
+        assert len(applicable_policies_catalog.applicable_policies) == 1
+        assert applicable_policies_catalog.applicable_policies[0].name == policy_name
+
+        # GET inherited APPLICABLE on table
+        applicable_for_table_inherit = test_policy_api.get_applicable_policies(
+            prefix=test_catalog.name,
+            namespace=format_namespace(sub_namespace_path),
+            target_name=table_name,
+        )
+        assert len(applicable_for_table_inherit.applicable_policies) == 1
+        assert applicable_for_table_inherit.applicable_policies[0].name == policy_name
+        assert applicable_for_table_inherit.applicable_policies[0].inherited
+
+        # DETACH from catalog
+        test_policy_api.detach_policy(
+            prefix=test_catalog.name,
+            namespace=namespace_name,
+            policy_name=policy_name,
+            detach_policy_request=DetachPolicyRequest(
+                target=PolicyAttachmentTarget(type="catalog")
+            ),
+        )
+
+        # GET APPLICABLE on catalog after DETACH
+        applicable_policies_catalog_after_detach = (
+            test_policy_api.get_applicable_policies(prefix=test_catalog.name)
+        )
+
+        assert len(applicable_policies_catalog_after_detach.applicable_policies) == 0
+
         # ATTACH to namespace
         test_policy_api.attach_policy(
             prefix=test_catalog.name,
@@ -282,11 +328,11 @@ def test_policies(
         )
 
         # GET APPLICABLE on namespace
-        applicable_policies = test_policy_api.get_applicable_policies(
+        applicable_policies_namespace = test_policy_api.get_applicable_policies(
             prefix=test_catalog.name, namespace=format_namespace(sub_namespace_path)
         )
-        assert len(applicable_policies.applicable_policies) == 1
-        assert applicable_policies.applicable_policies[0].name == policy_name
+        assert len(applicable_policies_namespace.applicable_policies) == 1
+        assert applicable_policies_namespace.applicable_policies[0].name == policy_name
 
         # DETACH from namespace
         test_policy_api.detach_policy(
@@ -299,10 +345,12 @@ def test_policies(
         )
 
         # GET APPLICABLE on namespace after DETACH
-        applicable_policies_after_detach = test_policy_api.get_applicable_policies(
-            prefix=test_catalog.name, namespace=format_namespace(sub_namespace_path)
+        applicable_policies_namespace_after_detach = (
+            test_policy_api.get_applicable_policies(
+                prefix=test_catalog.name, namespace=format_namespace(sub_namespace_path)
+            )
         )
-        assert len(applicable_policies_after_detach.applicable_policies) == 0
+        assert len(applicable_policies_namespace_after_detach.applicable_policies) == 0
 
         # ATTACH to table
         test_policy_api.attach_policy(
