@@ -17,12 +17,7 @@
 #  under the License.
 #
 
-from integration_tests.conftest import (
-    create_principal,
-    create_principal_role,
-    create_catalog_role,
-)
-from polaris.management import (
+from apache_polaris.sdk.management import (
     GrantPrincipalRoleRequest,
     GrantCatalogRoleRequest,
     AddGrantRequest,
@@ -33,6 +28,11 @@ from polaris.management import (
     Catalog,
     ResetPrincipalRequest,
 )
+from integration_tests.conftest import (
+    create_principal,
+    create_principal_role,
+    create_catalog_role,
+)
 
 
 def test_principals(management_client: PolarisDefaultApi) -> None:
