@@ -17,16 +17,15 @@
 # under the License.
 #
 
-import unittest
 import io
+import unittest
 from functools import reduce
 from typing import List
 from unittest.mock import patch, MagicMock
 
-from cli.command import Command
-from cli.options.parser import Parser
-from polaris.catalog import ApiClient
-from polaris.management import PolarisDefaultApi
+from apache_polaris.cli.command import Command
+from apache_polaris.cli.options.parser import Parser
+from apache_polaris.sdk.management import PolarisDefaultApi
 
 INVALID_ARGS = 2
 
@@ -618,6 +617,17 @@ class TestCliParsing(unittest.TestCase):
                 (1, 'client_secret'): 'e469c048cf866dfae469c048cf866df1',
             })
 
+    def test_policies_attach_parameters_parsed_to_dict(self):
+        options = Parser.parse([
+            'policies', 'attach', 'policy-name',
+            '--catalog', 'cat',
+            '--attachment-type', 'catalog',
+            '--parameters', 'key=value',
+        ])
+        command = Command.from_options(options)
+        self.assertIsInstance(command.parameters, dict)
+        self.assertEqual({'key': 'value'}, command.parameters)
+
 
 if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
+    unittest.main()
