@@ -92,7 +92,7 @@ public class PolarisIntegrationTestExtension implements ParameterResolver {
     private Env(Server server) {
       this.server = server;
       this.endpoints =
-          new PolarisApiEndpoints(server.baseUri(), server.realmId(), server.realmHeaderName());
+          new PolarisApiEndpoints(server.baseUri(), server.realmId(), server.headers());
     }
 
     PolarisApiEndpoints endpoints() {
