@@ -137,7 +137,9 @@ public abstract class PolarisRestCatalogViewIntegrationBase extends ViewCatalogT
             .setProperties(props)
             .setStorageConfigInfo(storageConfig)
             .build();
-    managementApi.createCatalog(principalRoleName, catalog);
+
+    createPolarisCatalog(catalog);
+    managementApi.makeAdmin(principalRoleName, catalog);
 
     restCatalog =
         IcebergHelper.restCatalog(
@@ -152,6 +154,11 @@ public abstract class PolarisRestCatalogViewIntegrationBase extends ViewCatalogT
     client.cleanUp(adminToken);
   }
 
+  /** Overridable methods to allow subclasses to execute additional logic on catalog creation. */
+  protected void createPolarisCatalog(Catalog catalog) {
+    managementApi.createCatalog(catalog);
+  }
+
   /**
    * @return The catalog's storage config.
    */
