@@ -100,6 +100,7 @@ public abstract class SparkIntegrationBase {
     CatalogProperties props = new CatalogProperties("s3://my-bucket/path/to/data");
     props.putAll(s3Container.getS3ConfigProperties());
     props.put("polaris.config.drop-with-purge.enabled", "true");
+    props.put("polaris.config.namespace-custom-location.enabled", "true");
     Catalog catalog =
         PolarisCatalog.builder()
             .setType(Catalog.TypeEnum.INTERNAL)
@@ -180,8 +181,8 @@ public abstract class SparkIntegrationBase {
               }
 
               Object value = row.get(pos);
-              if (value instanceof Row) {
-                return toJava((Row) value);
+              if (value instanceof Row valueRow) {
+                return toJava(valueRow);
               } else if (value instanceof scala.collection.Seq) {
                 return row.getList(pos);
               } else if (value instanceof scala.collection.Map) {
