@@ -70,7 +70,7 @@ public class BehaviorChangeConfiguration<T> extends PolarisConfiguration<T> {
               .key("TABLE_OPERATIONS_MAKE_METADATA_CURRENT_ON_COMMIT")
               .description(
                   "If true, BasePolarisTableOperations should mark the metadata that is passed into"
-                      + " `commit` as current, and re-use it to skip a trip to object storage to re-construct"
+                      + " `commit` as current, and reuse it to skip a trip to object storage to re-construct"
                       + " the committed metadata again.")
               .defaultValue(true)
               .buildBehaviorChangeConfiguration();
