@@ -72,7 +72,7 @@ public interface BasePersistence extends PolicyMappingPersistence {
    * or push down the return status enums from PolarisMetaStoreManager into this layer and document
    * accordingly.
    *
-   * <p>TODO: Change originalEntity to be just the set of members taht participate in conditions,
+   * <p>TODO: Change originalEntity to be just the set of members that participate in conditions,
    * similar to PolarisEntityCore, and make the callsites in BasePolarisCatalog actually plumb
    * through correctly, in particular for values the PolarisMetaStoreManagerImpl doesn't have access
    * to such as the original name and parentId in renames.
@@ -108,7 +108,7 @@ public interface BasePersistence extends PolicyMappingPersistence {
    * <p>TODO: Push down the multi-entity commit from PolarisMetaStoreManagerImpl to use this instead
    * of running single writeEntity actions within a transaction.
    *
-   * <p>TODO: Change originalEntity to be just the set of members taht participate in conditions,
+   * <p>TODO: Change originalEntity to be just the set of members that participate in conditions,
    * similar to PolarisEntityCore, and make the callsites in BasePolarisCatalog actually plumb
    * through correctly, in particular for values the PolarisMetaStoreManagerImpl doesn't have access
    * to such as the original name and parentId in renames.
@@ -279,7 +279,7 @@ public interface BasePersistence extends PolicyMappingPersistence {
 
   /**
    * List lightweight information of entities matching the given criteria with pagination. If all
-   * properties of the entity are required,use {@link #loadEntities} instead.
+   * properties of the entity are required,use {@link #listFullEntities} instead.
    *
    * @param callCtx call context
    * @param catalogId catalog id for that entity, NULL_ID if the entity is top-level
@@ -314,7 +314,7 @@ public interface BasePersistence extends PolicyMappingPersistence {
    * @return the paged list of matching entities after transformation
    */
   @Nonnull
-  <T> Page<T> loadEntities(
+  <T> Page<T> listFullEntities(
       @Nonnull PolarisCallContext callCtx,
       long catalogId,
       long parentId,
@@ -326,7 +326,7 @@ public interface BasePersistence extends PolicyMappingPersistence {
 
   /**
    * Lookup the current entityGrantRecordsVersion for the specified entity. That version is changed
-   * everytime a grant record is added or removed on a base securable or added to a grantee.
+   * every time a grant record is added or removed on a base securable or added to a grantee.
    *
    * @param callCtx call context
    * @param catalogId catalog id or NULL_ID
