@@ -21,9 +21,9 @@ package org.apache.polaris.core.persistence.resolver;
 
 import jakarta.annotation.Nonnull;
 import jakarta.annotation.Nullable;
-import jakarta.ws.rs.core.SecurityContext;
+import org.apache.polaris.core.auth.PolarisPrincipal;
 
 public interface ResolverFactory {
   Resolver createResolver(
-      @Nonnull SecurityContext securityContext, @Nullable String referenceCatalogName);
+      @Nonnull PolarisPrincipal principal, @Nullable String referenceCatalogName);
 }
