@@ -118,7 +118,7 @@ public abstract class BasePolarisMetaStoreManagerTest {
         .containsExactly(PolarisEntity.toCore(task1), PolarisEntity.toCore(task2));
 
     List<PolarisBaseEntity> listedEntities =
-        metaStoreManager.loadEntitiesAll(
+        metaStoreManager.listFullEntitiesAll(
             polarisTestMetaStoreManager.polarisCallContext,
             null,
             PolarisEntityType.TASK,
@@ -238,6 +238,12 @@ public abstract class BasePolarisMetaStoreManagerTest {
     polarisTestMetaStoreManager.testLookup();
   }
 
+  /** test batch entity load */
+  @Test
+  protected void testLoadResolvedEntitiesById() {
+    polarisTestMetaStoreManager.testLoadResolvedEntitiesById();
+  }
+
   /** Test the set of functions for the entity cache */
   @Test
   protected void testEntityCache() {
