@@ -32,17 +32,22 @@ import jakarta.enterprise.inject.Produces;
 import jakarta.inject.Singleton;
 import jakarta.ws.rs.container.ContainerRequestContext;
 import jakarta.ws.rs.core.Context;
+import jakarta.ws.rs.core.SecurityContext;
+import java.security.Principal;
 import java.time.Clock;
 import java.util.stream.Collectors;
 import org.apache.polaris.core.PolarisCallContext;
 import org.apache.polaris.core.PolarisDefaultDiagServiceImpl;
 import org.apache.polaris.core.PolarisDiagnostics;
+import org.apache.polaris.core.auth.DefaultPolarisAuthorizerFactory;
 import org.apache.polaris.core.auth.PolarisAuthorizer;
-import org.apache.polaris.core.auth.PolarisAuthorizerImpl;
+import org.apache.polaris.core.auth.PolarisAuthorizerFactory;
+import org.apache.polaris.core.auth.PolarisPrincipal;
 import org.apache.polaris.core.config.PolarisConfigurationStore;
 import org.apache.polaris.core.config.RealmConfig;
 import org.apache.polaris.core.context.CallContext;
 import org.apache.polaris.core.context.RealmContext;
+import org.apache.polaris.core.credentials.PolarisCredentialManager;
 import org.apache.polaris.core.persistence.BasePersistence;
 import org.apache.polaris.core.persistence.MetaStoreManagerFactory;
 import org.apache.polaris.core.persistence.PolarisMetaStoreManager;
@@ -54,6 +59,7 @@ import org.apache.polaris.core.persistence.resolver.Resolver;
 import org.apache.polaris.core.persistence.resolver.ResolverFactory;
 import org.apache.polaris.core.secrets.UserSecretsManager;
 import org.apache.polaris.core.secrets.UserSecretsManagerFactory;
+import org.apache.polaris.core.storage.StorageCredentialsVendor;
 import org.apache.polaris.core.storage.cache.StorageCredentialCache;
 import org.apache.polaris.core.storage.cache.StorageCredentialCacheConfig;
 import org.apache.polaris.service.auth.AuthenticationConfiguration;
@@ -70,6 +76,7 @@ import org.apache.polaris.service.catalog.io.FileIOFactory;
 import org.apache.polaris.service.context.RealmContextConfiguration;
 import org.apache.polaris.service.context.RealmContextFilter;
 import org.apache.polaris.service.context.RealmContextResolver;
+import org.apache.polaris.service.credentials.PolarisCredentialManagerConfiguration;
 import org.apache.polaris.service.events.PolarisEventListenerConfiguration;
 import org.apache.polaris.service.events.listeners.PolarisEventListener;
 import org.apache.polaris.service.persistence.PersistenceConfiguration;
@@ -77,6 +84,8 @@ import org.apache.polaris.service.ratelimiter.RateLimiter;
 import org.apache.polaris.service.ratelimiter.RateLimiterFilterConfiguration;
 import org.apache.polaris.service.ratelimiter.TokenBucketConfiguration;
 import org.apache.polaris.service.ratelimiter.TokenBucketFactory;
+import org.apache.polaris.service.reporting.MetricsReportingConfiguration;
+import org.apache.polaris.service.reporting.PolarisMetricsReporter;
 import org.apache.polaris.service.secrets.SecretsManagerConfiguration;
 import org.apache.polaris.service.storage.StorageConfiguration;
 import org.apache.polaris.service.storage.aws.S3AccessConfig;
@@ -137,10 +146,28 @@ public class ServiceProducers {
     return callContext.getRealmConfig();
   }
 
+  @Produces
+  @ApplicationScoped
+  @Identifier("internal")
+  public PolarisAuthorizerFactory defaultPolarisAuthorizerFactory() {
+    return new DefaultPolarisAuthorizerFactory();
+  }
+
+  @Produces
+  @ApplicationScoped
+  public PolarisAuthorizerFactory polarisAuthorizerFactory(
+      AuthorizationConfiguration authorizationConfig,
+      @Any Instance<PolarisAuthorizerFactory> authorizerFactories) {
+    PolarisAuthorizerFactory factory =
+        authorizerFactories.select(Identifier.Literal.of(authorizationConfig.type())).get();
+    return factory;
+  }
+
   @Produces
   @RequestScoped
-  public PolarisAuthorizer polarisAuthorizer(RealmConfig realmConfig) {
-    return new PolarisAuthorizerImpl(realmConfig);
+  public PolarisAuthorizer polarisAuthorizer(
+      PolarisAuthorizerFactory factory, RealmConfig realmConfig) {
+    return factory.create(realmConfig);
   }
 
   @Produces
@@ -154,12 +181,12 @@ public class ServiceProducers {
       PolarisMetaStoreManager polarisMetaStoreManager) {
     EntityCache entityCache =
         metaStoreManagerFactory.getOrCreateEntityCache(realmContext, realmConfig);
-    return (securityContext, referenceCatalogName) ->
+    return (principal, referenceCatalogName) ->
         new Resolver(
             diagnostics,
             callContext.getPolarisCallContext(),
             polarisMetaStoreManager,
-            securityContext,
+            principal,
             entityCache,
             referenceCatalogName);
   }
@@ -171,6 +198,20 @@ public class ServiceProducers {
     return new ResolutionManifestFactoryImpl(diagnostics, realmContext, resolverFactory);
   }
 
+  @Produces
+  @RequestScoped
+  public PolarisPrincipal polarisPrincipal(
+      PolarisDiagnostics diagnostics, @Context SecurityContext securityContext) {
+    Principal userPrincipal = securityContext.getUserPrincipal();
+    diagnostics.checkNotNull(userPrincipal, "null_security_context_principal");
+    diagnostics.check(
+        userPrincipal instanceof PolarisPrincipal,
+        "unexpected_principal_type",
+        "class={}",
+        userPrincipal.getClass().getName());
+    return (PolarisPrincipal) userPrincipal;
+  }
+
   // Polaris service beans - selected from @Identifier-annotated beans
 
   @Produces
@@ -180,6 +221,7 @@ public class ServiceProducers {
   }
 
   @Produces
+  @RequestScoped
   public FileIOFactory fileIOFactory(
       FileIOConfiguration config, @Any Instance<FileIOFactory> fileIOFactories) {
     return fileIOFactories.select(Identifier.Literal.of(config.type())).get();
@@ -206,6 +248,13 @@ public class ServiceProducers {
     return metaStoreManagerFactory.getOrCreateMetaStoreManager(realmContext);
   }
 
+  @Produces
+  @RequestScoped
+  public StorageCredentialsVendor storageCredentialsVendor(
+      PolarisMetaStoreManager metaStoreManager, CallContext callContext) {
+    return new StorageCredentialsVendor(metaStoreManager, callContext);
+  }
+
   @Produces
   public UserSecretsManagerFactory userSecretsManagerFactory(
       SecretsManagerConfiguration config,
@@ -349,13 +398,14 @@ public class ServiceProducers {
   @RequestScoped
   public TokenBroker tokenBroker(
       AuthenticationRealmConfiguration config,
-      RealmContext realmContext,
-      @Any Instance<TokenBrokerFactory> tokenBrokerFactories) {
+      @Any Instance<TokenBrokerFactory> tokenBrokerFactories,
+      PolarisMetaStoreManager polarisMetaStoreManager,
+      CallContext callContext) {
     String type =
         config.type() == AuthenticationType.EXTERNAL ? "none" : config.tokenBroker().type();
     TokenBrokerFactory tokenBrokerFactory =
         tokenBrokerFactories.select(Identifier.Literal.of(type)).get();
-    return tokenBrokerFactory.apply(realmContext);
+    return tokenBrokerFactory.create(polarisMetaStoreManager, callContext.getPolarisCallContext());
   }
 
   // other beans
@@ -392,7 +442,22 @@ public class ServiceProducers {
     return resolvers.select(Identifier.Literal.of(config.tenantResolver())).get();
   }
 
+  @Produces
+  @RequestScoped
+  public PolarisCredentialManager polarisCredentialManager(
+      PolarisCredentialManagerConfiguration config,
+      @Any Instance<PolarisCredentialManager> credentialManagers) {
+    return credentialManagers.select(Identifier.Literal.of(config.type())).get();
+  }
+
   public void closeTaskExecutor(@Disposes @Identifier("task-executor") ManagedExecutor executor) {
     executor.close();
   }
+
+  @Produces
+  @ApplicationScoped
+  public PolarisMetricsReporter metricsReporter(
+      MetricsReportingConfiguration config, @Any Instance<PolarisMetricsReporter> reporters) {
+    return reporters.select(Identifier.Literal.of(config.type())).get();
+  }
 }
