@@ -18,17 +18,10 @@
  */
 package org.apache.polaris.service.context.catalog;
 
-import jakarta.ws.rs.core.SecurityContext;
 import org.apache.iceberg.catalog.Catalog;
-import org.apache.polaris.core.auth.PolarisPrincipal;
-import org.apache.polaris.core.context.CallContext;
 import org.apache.polaris.core.persistence.resolver.PolarisResolutionManifest;
 
 public interface CallContextCatalogFactory {
 
-  Catalog createCallContextCatalog(
-      CallContext context,
-      PolarisPrincipal polarisPrincipal,
-      SecurityContext securityContext,
-      PolarisResolutionManifest resolvedManifest);
+  Catalog createCallContextCatalog(PolarisResolutionManifest resolvedManifest);
 }
