@@ -51,13 +51,12 @@ public class PolarisAdminServiceAuthzTest extends PolarisAuthzTestBase {
     final PolarisPrincipal authenticatedPrincipal =
         PolarisPrincipal.of(principalEntity, activatedPrincipalRoles);
     return new PolarisAdminService(
-        diagServices,
         callContext,
         resolutionManifestFactory,
         metaStoreManager,
         userSecretsManager,
         serviceIdentityProvider,
-        securityContext(authenticatedPrincipal),
+        authenticatedPrincipal,
         polarisAuthorizer,
         reservedProperties);
   }
